document.addEventListener('DOMContentLoaded', () => {
  const notesGrid = document.querySelector('.notes-grid');
  const noteTemplate = document.getElementById('note-template');
  const newNoteBtn = document.getElementById('new-note');
  const typeButtons = document.querySelectorAll('.note-type-selector button');

  let currentNoteType = 'text';

  // Handle note type selection
  typeButtons.forEach(button => {
    button.addEventListener('click', () => {
      typeButtons.forEach(btn => btn.classList.remove('active'));
      button.classList.add('active');
      currentNoteType = button.dataset.type;
    });
  });

  // Create new note
  newNoteBtn.addEventListener('click', () => {
    const noteClone = noteTemplate.content.cloneNode(true);
    const noteContent = noteClone.querySelector('.note-content');
    
    switch(currentNoteType) {
      case 'text':
        noteContent.innerHTML = `<textarea placeholder="Start typing your note..."></textarea>`;
        break;
      case 'image':
        noteContent.innerHTML = `
          <input type="file" accept="image/*" class="image-upload">
          <div class="image-preview"></div>
        `;
        break;
      case 'video':
        noteContent.innerHTML = `
          <input type="url" placeholder="Paste video URL here" class="video-url">
          <div class="video-preview"></div>
        `;
        break;
    }

    // Add event listeners for new note
    const noteElement = noteClone.querySelector('.note');
    const deleteBtn = noteElement.querySelector('.delete');
    const editBtn = noteElement.querySelector('.edit');

    deleteBtn.addEventListener('click', () => {
      noteElement.remove();
    });

    editBtn.addEventListener('click', () => {
      // Implement edit functionality
      alert('Edit functionality coming soon!');
    });

    notesGrid.prepend(noteElement);
  });

  // Handle image upload preview
  notesGrid.addEventListener('change', (e) => {
    if (e.target.classList.contains('image-upload')) {
      const file = e.target.files[0];
      const preview = e.target.nextElementSibling;
      
      if (file) {
        const reader = new FileReader();
        reader.onload = (event) => {
          preview.innerHTML = `<img src="${event.target.result}" alt="Uploaded image">`;
        };
        reader.readAsDataURL(file);
      }
    }
  });

  // Handle video URL input
  notesGrid.addEventListener('input', (e) => {
    if (e.target.classList.contains('video-url')) {
      const url = e.target.value;
      const preview = e.target.nextElementSibling;
      
      if (url) {
        preview.innerHTML = `
          <iframe 
            src="${url}" 
            frameborder="0" 
            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" 
            allowfullscreen>
          </iframe>
        `;
      } else {
        preview.innerHTML = '';
      }
    }
  });
});